@@ -3,7 +3,7 @@ use strict;
 
 package Devel::Chitin;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Scalar::Util;
 use IO::File;
@@ -302,6 +302,7 @@ sub cleanup {}
 sub notify_stopped {}
 sub notify_resumed {}
 sub notify_trace {}
+sub notify_trace_resumed {}
 sub notify_fork_parent {}
 sub notify_fork_child {}
 sub notify_program_terminated {}
@@ -443,8 +444,9 @@ sub is_breakpoint {
 sub _parent_stack_location {
     my($package, $filename, $line) = caller(1);
     my(undef, undef, undef, $subname) = caller(2);
+    my $callsite = Devel::Chitin::Location::get_callsite(2);
     $subname ||= 'MAIN';
-    return ($package, $filename, $line, $subname);
+    return ($package, $filename, $line, $subname, $callsite);
 }
 
 BEGIN {
@@ -453,12 +455,13 @@ BEGIN {
         my $pid = CORE::fork();
         return $pid unless $ready;
 
-        my($package, $filename, $line, $subname) = _parent_stack_location();
+        my($package, $filename, $line, $subname, $callsite) = _parent_stack_location();
         my $location = Devel::Chitin::Location->new(
             'package'   => $package,
             line        => $line,
             filename    => $filename,
             subroutine  => $subname,
+            callsite    => $callsite,
         );
 
         my $notify = $pid ? 'notify_fork_parent' : 'notify_fork_child';
@@ -483,7 +486,7 @@ $SIG{__DIE__} = sub {
         # (which it correctly does with no args), it returns the line which
         # called the function which threw the exception.
         # We'll work around it by calling it twice
-        my($package, $filename, $line, $subname) = _parent_stack_location();
+        my($package, $filename, $line, $subname, $callsite) = _parent_stack_location();
 
         $uncaught_exception = Devel::Chitin::Exception->new(
             'package'   => $package,
@@ -491,6 +494,7 @@ $SIG{__DIE__} = sub {
             filename    => $filename,
             exception   => $exception,
             subroutine  => $subname,
+            callsite    => $callsite,
         );
         # After we fall off the end, the interpreter will try and exit,
         # triggering the END block that calls DB::fake::at_exit()
@@ -550,6 +554,7 @@ sub DB {
         filename    => $filename,
         line        => $line,
         subroutine  => $subroutine,
+        callsite    => scalar Devel::Chitin::Location::get_callsite(),
     );
 
     $_->notify_trace($current_location) foreach values(%trace_clients);
@@ -590,6 +595,8 @@ sub DB {
 
     RETURN_TO_DEBUGGED_PROGRAM:
 
+    $_->notify_trace_resumed($current_location) foreach values(%trace_clients);
+
     $previous_location = $current_location;
     undef $current_location;
     Devel::Chitin::Stack::invalidate();
@@ -736,6 +743,7 @@ Devel::Chitin - Programmatic interface to the Perl debugging API
   CLIENT->poll($location);              # Return true if there is user input
   CLIENT->idle($location);              # Handle user interaction (can block)
   CLIENT->notify_trace($location);      # Called on each executable statement
+  CLIENT->notify_trace_resumed($location);  # Called before the program gets control after trace
   CLIENT->notify_stopped($location);    # Called when a break has occured
   CLIENT->notify_resumed($location);    # Called before the program gets control after a break
   CLIENT->notify_fork_parent($location,$pid);   # Called after fork() in parent
@@ -787,7 +795,9 @@ C<attach> call.
 =item CLIENT->trace([1 | 0])
 
 Get or set the trace flag.  If trace is on, the client will get notified
-before every executable statement by having its C<notify_trace> method called.
+before every executable statement by having its C<notify_trace> method called,
+and before returning to the debugged program by having its
+C<notify_trace_resumed> method called.
 
 =item CLIENT->disable_debugger()
 
@@ -925,8 +935,8 @@ watched expression's value ever changes, the client that added the expression
 will be notified via its C<notify_watch_expr()> method.  These expressions
 are always evaluated in list context.  They are considered changed if the
 list's length changes, or if one of the elements has a different value
-when compared as strings.  This comparison is only a shallow; it will not
-recurse deeply into references.
+when compared as strings.  This comparison is only shallow; it will not
+recurse into references or nested data structures.
 
 =over 4
 
@@ -977,6 +987,11 @@ each executable statement.  The return value is ignored.  $location is an
 instance of L<Devel::Chitin::Location> indicating the next statement to be
 executed in the debugged program.
 
+=item CLIENT->notify_trace_resumed($location)
+
+If a client has turned on the trace flag, this method will be called before
+the debugged program regains control.  The return value is ignored.
+
 notify_trace() will be called only on clients that have requested tracing by
 calling CLIENT->trace(1).
 
